==> ejc-procurement-api-3.0.0-20251215.045507-118-sources.jar: com/ejianc/business/procurement/perform/vo/FileAnswerVO.java <==
package com.ejianc.business.procurement.perform.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;


/**
 * 应答文件审批档案
 * 
 * @author generator
 * 
 */
public class FileAnswerVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String score; // 分值
    private Integer enabled; // 启停用
    private String content; // 评价项目
    private String secCode; // 序号
    private String remark; // 备注
    private Long pid;// 父级id

    private List<FileAnswerVO> children = new ArrayList<>() ;

    public List<FileAnswerVO> getChildren() {
        return children;
    }

    public void setChildren(List<FileAnswerVO> children) {
        this.children = children;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public String getScore() {
        return score;
    }

    public void setScore(String score) {
        this.score = score;
    }
    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }
    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }
    public String getSecCode() {
        return secCode;
    }

    public void setSecCode(String secCode) {
        this.secCode = secCode;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}

==> ejc-procurement-api-3.0.0-20251215.064104-120-sources.jar: com/ejianc/business/procurement/perform/vo/FileAnswerVO.java <==
package com.ejianc.business.procurement.perform.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;


/**
 * 应答文件审批档案
 * 
 * @author generator
 * 
 */
public class FileAnswerVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer score; // 分值
    private Boolean enabled; // 启停用
    private String content; // 评价项目
    private String secCode; // 序号
    private String remark; // 备注
    private Long pid;// 父级id

    private List<FileAnswerVO> children = new ArrayList<>() ;

    public List<FileAnswerVO> getChildren() {
        return children;
    }

    public void setChildren(List<FileAnswerVO> children) {
        this.children = children;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Integer getScore() {
        return score;
    }

    public void setScore(Integer score) {
        this.score = score;
    }
    public Boolean getEnabled() {
        return enabled;
    }

    public void setEnabled(Boolean enabled) {
        this.enabled = enabled;
    }
    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }
    public String getSecCode() {
        return secCode;
    }

    public void setSecCode(String secCode) {
        this.secCode = secCode;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}
